#!/bin/bash
set -e
set -vx

echo " Set environment"
export dir=./out
export cadir=./out/ca
export format=pem

if ! [ -d $dir ]
then
    mkdir $dir
    mkdir -p $dir/certs $dir/crl $dir/csr $dir/newcerts $dir/privates $dir/serials $dir/publics $dir/trusted
fi

echo "--------------------------------------------------------------------------------------"
echo " Generate Test System Signing Certificate"

# For OCSP support use uncomment these:
ocspurl=ocsp.www.fscom.fr
export ocspIAI="OCSP;URI:http://$ocspurl"

countryName="/C=FR"
stateOrProvinceName="/ST=AM"
localityName="/L=Sophia-Antipolis"
organizationName="/O=ETSI"
organizationalUnitName="/OU=Plugtests"
commonName="/CN=plugtests.net"
DN=$countryName$stateOrProvinceName$localityName
DN=$DN$organizationName$organizationalUnitName$commonName
echo $DN
ConfTestID=plugtestsit
echo $ConfTestID > $dir/privates/ConfTestID_rsa.txt
sleep 1
cse_fqdn=etsi.org
emailaddr=${ConfTestID}@${cse_fqdn}
export subjectAltName="email:$emailaddr"
echo $subjectAltName

echo " Generate serial number"
openssl rand -hex $sn > $dir/serials/${ConfTestID}_server_rsa.srl
echo " Generate private Key"
openssl genrsa -out $dir/privates/${ConfTestID}_server_rsa.key.$format $key_size
echo " View key"
openssl rsa -inform $format -in $dir/privates/${ConfTestID}_server_rsa.key.$format -text -noout
#chmod 400 $dir/privates/${ConfTestID}_server_rsa.$format
echo " Create the CSR for Server Certificate file"
openssl req -config ./ca_intermediate_rsa.cfg -key $dir/privates/${ConfTestID}_server_rsa.key.$format -subj "$DN" -new -sha256 -out $dir/csr/${ConfTestID}_server_rsa.csr.$format
openssl req -text -noout -verify -in $dir/csr/${ConfTestID}_server_rsa.csr.$format
echo " Create Server Certificate file"
cp $dir/serials/${ConfTestID}_server_rsa.srl $dir/serial # hex 8 is minimum, 19 is maximum
# Note 'openssl ca' does not support DER format
openssl x509 -req -sha256 -days 375 -extensions server_cert -CA PCA-root-ca-cert.ccc -in $dir/csr/${ConfTestID}_server_rsa.csr.$format -out $dir/certs/${ConfTestID}_server_rsa.cert.$format
#chmod 444 $dir/certs/${ConfTestID}_server_rsa.cert.$format
echo " View Server Certificate"
openssl x509 -noout -text -in $dir/certs/${ConfTestID}_server_rsa.cert.$format
echo " Verify Server Certificate"
openssl verify -CAfile PCA-root-ca-cert.ccc $dir/certs/${ConfTestID}_server_rsa.cert.$format
echo " Extract public key"
openssl x509 -in $dir/certs/${ConfTestID}_server_rsa.cert.$format -pubkey -out $dir/publics/${ConfTestID}_server_rsa.pub.$format
